Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GenerateFile ¶
GenerateFile generates a _errors.pb.go file containing kratos errors definitions This is the main entry point for error code generation from protobuf files
从 protobuf 文件生成包含 kratos 错误定义的 _errors.pb.go 文件 这是从 protobuf 文件生成错误代码的主要入口点
Types ¶
type Config ¶
type Config struct {
GeneratorName string // e.g. "protoc-gen-go-errors" or "protoc-gen-orzkratos-errors"
IncludeNested bool // Include nested enums in generation
SeparateNamed bool // Use underscore separator in nested enum function names (e.g. ErrorGetUserResponse_UserNotFound)
}
Config holds generation configuration
Click to show internal directories.
Click to hide internal directories.